[Updated] D9664: actions: rename DEFICIENCY constant to FORMAT_VARIANT

pulkit (Pulkit Goyal) phabricator at mercurial-scm.org
Tue Jan 12 23:53:19 UTC 2021


Closed by commit rHG9540945e51fd: actions: rename DEFICIENCY constant to FORMAT_VARIANT (authored by pulkit).
This revision was automatically updated to reflect the committed changes.

REPOSITORY
  rHG Mercurial

CHANGES SINCE LAST UPDATE
  https://phab.mercurial-scm.org/D9664?vs=24542&id=24750

CHANGES SINCE LAST ACTION
  https://phab.mercurial-scm.org/D9664/new/

REVISION DETAIL
  https://phab.mercurial-scm.org/D9664

AFFECTED FILES
  mercurial/upgrade_utils/actions.py

CHANGE DETAILS

diff --git a/mercurial/upgrade_utils/actions.py b/mercurial/upgrade_utils/actions.py
--- a/mercurial/upgrade_utils/actions.py
+++ b/mercurial/upgrade_utils/actions.py
@@ -28,7 +28,7 @@
     return set()
 
 
-DEFICIENCY = b'deficiency'
+FORMAT_VARIANT = b'deficiency'
 OPTIMISATION = b'optimization'
 
 
@@ -42,13 +42,15 @@
        will be mapped to an action later in the upgrade process.
 
     type
-       Either ``DEFICIENCY`` or ``OPTIMISATION``. A deficiency is an obvious
-       problem. An optimization is an action (sometimes optional) that
+       Either ``FORMAT_VARIANT`` or ``OPTIMISATION``.
+       A format variant is where we change the storage format. Not all format
+       variant changes are an obvious problem.
+       An optimization is an action (sometimes optional) that
        can be taken to further improve the state of the repository.
 
     description
        Message intended for humans explaining the improvement in more detail,
-       including the implications of it. For ``DEFICIENCY`` types, should be
+       including the implications of it. For ``FORMAT_VARIANT`` types, should be
        worded in the present tense. For ``OPTIMISATION`` types, should be
        worded in the future tense.
 
@@ -87,7 +89,7 @@
 class formatvariant(improvement):
     """an improvement subclass dedicated to repository format"""
 
-    type = DEFICIENCY
+    type = FORMAT_VARIANT
     ### The following attributes should be defined for each class:
 
     # machine-readable string uniquely identifying this improvement. it will be
@@ -95,7 +97,8 @@
     name = None
 
     # message intended for humans explaining the improvement in more detail,
     # including the implications of it ``DEFICIENCY`` types, should be worded
     # in the present tense.
     description = None
 



To: pulkit, #hg-reviewers, marmoute, mharbison72
Cc: joerg.sonnenberger, mercurial-patches
-------------- next part --------------
@@ -95,7 +97,8 @@
 
     # message intended for humans explaining the improvement in more detail,
-    # including the implications of it ``DEFICIENCY`` types, should be worded
+    # including the implications of it ``FORMAT_VARIANT`` types, should be
+    # worded
     # in the present tense.
     description = None
An HTML attachment was scrubbed...
URL: <http://lists.mercurial-scm.org/pipermail/mercurial-patches/attachments/20210112/daad66c3/attachment-0002.html>


More information about the Mercurial-patches mailing list